@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Acme::CPANLists;
 
-our $DATE = '2016-02-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-07-28'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -115,12 +115,42 @@ sub munge_file {
     }
 
     my $abstract = $self->_get_abstract_from_author_or_module_list($file->name, $file->content);
-    return unless $abstract;
 
-    $content =~ s{^#\s*ABSTRACT:.*}{# ABSTRACT: $abstract}m
-        or die "Can't insert abstract for " . $file->name;
-    $self->log(["inserting abstract for %s (%s)", $file->name, $abstract]);
-    $file->content($content);
+  ADD_X_MENTIONS_PREREQS:
+    {
+        my $pkg = do {
+            my $pkg = $file->name;
+            $pkg =~ s!^lib/!!;
+            $pkg =~ s!\.pm$!!;
+            $pkg =~ s!/!::!g;
+            $pkg;
+        };
+        no strict 'refs';
+        #my $author_lists = \@{"$pkg\::Author_Lists"};
+        my $module_lists = \@{"$pkg\::Module_Lists"};
+        my @mods;
+        for my $module_list (@$module_lists) {
+            for my $entry (@{ $module_list->{entries} }) {
+                push @mods, $entry->{module};
+                for (@{ $entry->{alternate_modules} || [] }) {
+                    push @mods, $_;
+                }
+            }
+        }
+        for my $mod (@mods) {
+            $self->zilla->register_prereqs(
+                {phase=>'x_mentions', type=>'x_mentions'}, $mod, 0);
+        }
+    }
+
+  SET_ABSTRACT:
+    {
+        last unless $abstract;
+        $content =~ s{^#\s*ABSTRACT:.*}{# ABSTRACT: $abstract}m
+            or die "Can't insert abstract for " . $file->name;
+        $self->log(["inserting abstract for %s (%s)", $file->name, $abstract]);
+        $file->content($content);
+    }
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -139,7 +169,7 @@ Dist::Zilla::Plugin::Acme::CPANLists - Plugin to use when building Acme::CPANLis
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::Acme::CPANLists (from Perl distribution Dist-Zilla-Plugin-Acme-CPANLists), released on 2016-02-21.
+This document describes version 0.03 of Dist::Zilla::Plugin::Acme::CPANLists (from Perl distribution Dist-Zilla-Plugin-Acme-CPANLists), released on 2017-07-28.
 
 =head1 SYNOPSIS
 
@@ -156,6 +186,8 @@ currently does the following:
 
 =item * Fill the Abstract from the first module/author list's summary
 
+=item * Add prereq to the mentioned modules (phase=x_mentions, relationship=x_mentions)
+
 =back
 
 =for Pod::Coverage .+
@@ -188,7 +220,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
